@@ -44,4 +44,22 @@ module ReportsHelper
     parameters = {:set_filter => 1, :subproject_id => '!*', field => (row.id || '!*')}.merge(options)
     project_issues_path(row.is_a?(Project) ? row : project, parameters)
   end
+
+  def issue_report_details_to_csv(field_name, statuses, rows, data)
+    Redmine::Export::CSV.generate(:encoding => params[:encoding]) do |csv|
+      # csv headers
+      headers = [''] + statuses.map(&:name) + [l(:label_open_issues_plural), l(:label_closed_issues_plural), l(:label_total)]
+      csv << headers
+
+      # csv lines
+      rows.each do |row|
+        csv <<
+          [row.name] +
+          statuses.map{|s| aggregate(data, { field_name => row.id, 'status_id' => s.id })} +
+          [aggregate(data, { field_name => row.id, 'closed' => 0 })] +
+          [aggregate(data, { field_name => row.id, 'closed' => 1 })] +
+          [aggregate(data, { field_name => row.id })]
+      end
+    end
+  end
 end
