@@ -31,6 +31,7 @@ class IssueStatus < ActiveRecord::Base
   validates_presence_of :name
   validates_uniqueness_of :name, :case_sensitive => true
   validates_length_of :name, :maximum => 30
+  validates_length_of :description, :maximum => 255
   validates_inclusion_of :default_done_ratio, :in => 0..100, :allow_nil => true
 
   scope :sorted, lambda {order(:position)}
@@ -38,6 +39,7 @@ class IssueStatus < ActiveRecord::Base
 
   safe_attributes(
     'name',
+    'description',
     'is_closed',
     'position',
     'default_done_ratio')
@@ -82,6 +84,8 @@ class IssueStatus < ActiveRecord::Base
   end
 
   def <=>(status)
+    return nil unless status.is_a?(IssueStatus)
+
     position <=> status.position
   end
 
