@@ -193,9 +193,9 @@ class Repository::Mercurial < Repository
     (db_rev + 1).step(scm_rev, FETCH_AT_ONCE) do |i|
       scm.each_revision('', i, [i + FETCH_AT_ONCE - 1, scm_rev].min) do |re|
         transaction do
-          parents = (re.parents || []).collect do |rp|
+          parents = (re.parents || []).filter_map do |rp|
             find_changeset_by_name(scmid_for_inserting_db(rp))
-          end.compact
+          end
           cs = Changeset.create(:repository   => self,
                                 :revision     => re.revision,
                                 :scmid        => scmid_for_inserting_db(re.scmid),
