@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2021  Jean-Philippe Lang
+# Copyright (C) 2006-2023  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require 'diff'
+require 'redmine/string_array_diff/diff'
 
 class WikiPage < ActiveRecord::Base
   include Redmine::SafeAttributes
@@ -273,7 +273,7 @@ class WikiPage < ActiveRecord::Base
   protected
 
   def validate_parent_title
-    errors.add(:parent_title, :invalid) if !@parent_title.blank? && parent.nil?
+    errors.add(:parent_title, :invalid) if @parent_title.present? && parent.nil?
     errors.add(:parent_title, :circular_dependency) if parent && (parent == self || parent.ancestors.include?(self))
     if parent_id_changed? && parent && (parent.wiki_id != wiki_id)
       errors.add(:parent_title, :not_same_project)
@@ -286,56 +286,3 @@ class WikiPage < ActiveRecord::Base
     (association(:content).loaded? ? content : content_without_text).try(name)
   end
 end
-
-class WikiDiff < Redmine::Helpers::Diff
-  attr_reader :content_to, :content_from
-
-  def initialize(content_to, content_from)
-    @content_to = content_to
-    @content_from = content_from
-    super(content_to.text, content_from.text)
-  end
-end
-
-class WikiAnnotate
-  attr_reader :lines, :content
-
-  def initialize(content)
-    @content = content
-    current = content
-    current_lines = current.text.split(/\r?\n/)
-    @lines = current_lines.collect {|t| [nil, nil, t]}
-    positions = []
-    current_lines.size.times {|i| positions << i}
-    while current.previous
-      d = current.previous.text.split(/\r?\n/).diff(current.text.split(/\r?\n/)).diffs.flatten
-      d.each_slice(3) do |s|
-        sign, line = s[0], s[1]
-        if sign == '+' && positions[line] && positions[line] != -1
-          if @lines[positions[line]][0].nil?
-            @lines[positions[line]][0] = current.version
-            @lines[positions[line]][1] = current.author
-          end
-        end
-      end
-      d.each_slice(3) do |s|
-        sign, line = s[0], s[1]
-        if sign == '-'
-          positions.insert(line, -1)
-        else
-          positions[line] = nil
-        end
-      end
-      positions.compact!
-      # Stop if every line is annotated
-      break unless @lines.detect {|line| line[0].nil?}
-
-      current = current.previous
-    end
-    @lines.each do |line|
-      line[0] ||= current.version
-      # if the last known version is > 1 (eg. history was cleared), we don't know the author
-      line[1] ||= current.author if current.version == 1
-    end
-  end
-end
