@@ -60,7 +60,7 @@ module Redmine
           right << [l(:field_estimated_hours), l_hours(issue.estimated_hours)] unless issue.disabled_core_fields.include?('estimated_hours')
           right << [l(:label_spent_time), l_hours(issue.total_spent_hours)] if User.current.allowed_to?(:view_time_entries, issue.project)
 
-          rows = left.size > right.size ? left.size : right.size
+          rows = [left.size, right.size].max
           left  << nil while left.size  < rows
           right << nil while right.size < rows
 
@@ -82,7 +82,7 @@ module Redmine
             border_last  = 'R'
           end
 
-          rows = left.size > right.size ? left.size : right.size
+          rows = [left.size, right.size].max
           rows.times do |i|
             heights = []
             pdf.SetFontStyle('B', 9)
@@ -339,7 +339,7 @@ module Redmine
                   issue.visible_custom_field_values.detect do |v|
                     v.custom_field_id == column.custom_field.id
                   end
-                is_html = cv.custom_field.full_text_formatting?
+                is_html = cv.custom_field.full_text_formatting? if cv
                 text = show_value(cv, is_html)
               else
                 text = pdf_format_text issue, column.name.to_sym
