@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2022  Jean-Philippe Lang
+# Copyright (C) 2006-2023  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -77,7 +77,7 @@ module Redmine
 
       def last_item
         l = first_item + per_page - 1
-        l > item_count ? item_count : l
+        [l, item_count].min
       end
 
       def linked_pages
