@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.expand_path('../../test_helper', __FILE__)
+require_relative '../test_helper'
 
 class AccountControllerTest < Redmine::ControllerTest
   fixtures :users, :email_addresses, :roles
@@ -476,6 +476,7 @@ class AccountControllerTest < Redmine::ControllerTest
         }
       )
       assert_response :success
+      assert_equal I18n.t(:notice_account_lost_email_sent), flash[:notice]
     end
   end
 
