@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2021  Jean-Philippe Lang
+# Copyright (C) 2006-2023  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.expand_path('../../test_helper', __FILE__)
+require_relative '../test_helper'
 
 class AttachmentsControllerTest < Redmine::ControllerTest
   fixtures :users, :user_preferences, :projects, :roles, :members, :member_roles,
@@ -157,7 +157,7 @@ class AttachmentsControllerTest < Redmine::ControllerTest
     assert_response :success
     assert_equal 'text/html', @response.media_type
     assert_select 'tr#L1' do
-      assert_select 'th.line-num', :text => '1'
+      assert_select 'th.line-num a[data-txt=?]', '1'
       assert_select 'td', :text => /日本語/
     end
   end
@@ -174,7 +174,7 @@ class AttachmentsControllerTest < Redmine::ControllerTest
       assert_response :success
       assert_equal 'text/html', @response.media_type
       assert_select 'tr#L7' do
-        assert_select 'th.line-num', :text => '7'
+        assert_select 'th.line-num a[data-txt=?]', '7'
         assert_select 'td', :text => /Demande cr\?\?e avec succ\?s/
       end
     end
@@ -192,7 +192,7 @@ class AttachmentsControllerTest < Redmine::ControllerTest
       assert_response :success
       assert_equal 'text/html', @response.media_type
       assert_select 'tr#L7' do
-        assert_select 'th.line-num', :text => '7'
+        assert_select 'th.line-num a[data-txt=?]', '7'
         assert_select 'td', :text => /Demande créée avec succès/
       end
     end
@@ -209,7 +209,7 @@ class AttachmentsControllerTest < Redmine::ControllerTest
     end
   end
 
-  def test_show_text_file_formated_markdown
+  def test_show_text_file_formatted_markdown
     set_tmp_attachments_directory
     a = Attachment.new(:container => Issue.find(1),
                        :file => uploaded_test_file('testfile.md', 'text/plain'),
@@ -219,10 +219,10 @@ class AttachmentsControllerTest < Redmine::ControllerTest
     get(:show, :params => {:id => a.id})
     assert_response :success
     assert_equal 'text/html', @response.media_type
-    assert_select 'div.wiki', :html => "<h1>Header 1</h1>\n\n<h2>Header 2</h2>\n\n<h3>Header 3</h3>"
+    assert_select 'div.wiki', :html => "<h1>Header 1</h1>\n<h2>Header 2</h2>\n<h3>Header 3</h3>"
   end
 
-  def test_show_text_file_fromated_textile
+  def test_show_text_file_formatted_textile
     set_tmp_attachments_directory
     a = Attachment.new(:container => Issue.find(1),
                        :file => uploaded_test_file('testfile.textile', 'text/plain'),
@@ -491,17 +491,6 @@ class AttachmentsControllerTest < Redmine::ControllerTest
     assert_select 'h2 a', :text => "Feature request #2"
   end
 
-  def test_edit_all_with_invalid_container_class_should_return_404
-    get(
-      :edit_all,
-      :params => {
-        :object_type => 'nuggets',
-        :object_id => '3'
-      }
-    )
-    assert_response 404
-  end
-
   def test_edit_all_with_invalid_object_should_return_404
     get(
       :edit_all,
@@ -634,6 +623,22 @@ class AttachmentsControllerTest < Redmine::ControllerTest
     assert_response 404
   end
 
+  def test_download_all_with_invisible_journal
+    Project.find(1).update_column :is_public, false
+    Member.delete_all
+    @request.session[:user_id] = 2
+    User.current = User.find(2)
+    assert_not Journal.find(3).journalized.visible?
+    get(
+      :download_all,
+      :params => {
+        :object_type => 'journals',
+        :object_id => '3'
+      }
+    )
+    assert_response 403
+  end
+
   def test_download_all_with_maximum_bulk_download_size_larger_than_attachments
     with_settings :bulk_download_max_size => 0 do
       @request.session[:user_id] = 2
@@ -642,7 +647,23 @@ class AttachmentsControllerTest < Redmine::ControllerTest
         :params => {
           :object_type => 'issues',
           :object_id => '2',
-          :back_url => '/issues/2'
+          :back_url => '/issues/123'
+        }
+      )
+      assert_redirected_to '/issues/123'
+      assert_equal flash[:error], 'These attachments cannot be bulk downloaded because the total file size exceeds the maximum allowed size (0 Bytes)'
+    end
+  end
+
+  def test_download_all_redirects_to_container_url_on_error
+    with_settings :bulk_download_max_size => 0 do
+      @request.session[:user_id] = 2
+      get(
+        :download_all,
+        :params => {
+          :object_type => 'issues',
+          :object_id => '2',
+          :back_url => 'https://example.com'
         }
       )
       assert_redirected_to '/issues/2'
