@@ -17,12 +17,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.expand_path('../../test_helper', __FILE__)
+require_relative '../test_helper'
 
 class MailHandlerControllerTest < Redmine::ControllerTest
   fixtures :users, :email_addresses, :projects, :enabled_modules,
            :roles, :members, :member_roles, :issues, :issue_statuses,
-           :trackers, :projects_trackers, :enumerations
+           :trackers, :projects_trackers, :enumerations, :versions
 
   FIXTURES_PATH = File.dirname(__FILE__) + '/../fixtures/mail_handler'
 
