@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.expand_path('../../test_helper', __FILE__)
+require_relative '../test_helper'
 
 class TimelogReportTest < Redmine::ControllerTest
   tests TimelogController
@@ -110,8 +110,8 @@ class TimelogReportTest < Redmine::ControllerTest
     get :report, :params => {:project_id => 1, :columns => 'month', :criteria => ["user", "activity"]}
     assert_response :success
 
-    assert_select 'td.name a.user.active[href=?]', '/users/1', 1, :text => 'Redmine Admin'
-    assert_select 'td.name a.user.locked[href=?]', '/users/2', 1, :text => 'John Smith'
+    assert_select 'td.name a.user.active[href=?]', '/users/1', :text => 'Redmine Admin', :count => 1
+    assert_select 'td.name a.user.locked[href=?]', '/users/2', :text => 'John Smith', :count => 1
   end
 
   def test_report_custom_field_criteria_with_multiple_values_on_single_value_custom_field_should_not_fail
@@ -231,7 +231,7 @@ class TimelogReportTest < Redmine::ControllerTest
     get :report, :params => {:project_id => 1, :criteria => ['activity']}
     assert_response :success
 
-    assert_select 'tr.last-level:first' do
+    assert_select 'tr.last-level' do
       assert_select 'td.name', :text => 'Design'
       assert_select 'td.hours:last', :text => '165:15'
     end
