@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Redmine - project management software
-# Copyright (C) 2006-2022  Jean-Philippe Lang
+# Copyright (C) 2006-2023  Jean-Philippe Lang
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.expand_path('../../test_helper', __FILE__)
+require_relative '../test_helper'
 
 class WikisControllerTest < Redmine::ControllerTest
   fixtures :projects, :users, :roles, :members, :member_roles, :enabled_modules, :wikis
@@ -35,13 +35,17 @@ class WikisControllerTest < Redmine::ControllerTest
     end
   end
 
-  def test_post_destroy_should_delete_wiki
+  def test_post_destroy_should_reinitialize_empty_wiki
     set_tmp_attachments_directory
     @request.session[:user_id] = 1
+    wiki = Project.find(1).wiki
     post :destroy, :params => {:id => 1, :confirm => 1}
     assert_redirected_to :controller => 'projects',
                          :action => 'show', :id => 'ecookbook'
-    assert_nil Project.find(1).wiki
+
+    new_wiki = Project.find(1).wiki
+    assert_not_equal wiki, new_wiki
+    assert_equal "Wiki", new_wiki.start_page
   end
 
   def test_not_found
