@@ -17,11 +17,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.expand_path('../../application_system_test_case', __FILE__)
+require_relative '../application_system_test_case'
 
 class IssuesSystemTest < ApplicationSystemTestCase
   fixtures :projects, :users, :email_addresses, :roles, :members, :member_roles,
-           :trackers, :projects_trackers, :enabled_modules, :issue_statuses, :issues,
+           :trackers, :projects_trackers, :enabled_modules,
+           :issue_statuses, :issues, :issue_categories,
            :enumerations, :custom_fields, :custom_values, :custom_fields_trackers,
            :watchers, :journals, :journal_details, :versions,
            :workflows
@@ -45,7 +46,7 @@ class IssuesSystemTest < ApplicationSystemTestCase
     assert_kind_of Issue, issue
 
     # check redirection
-    find 'div#flash_notice', :visible => true, :text => "Issue \##{issue.id} created."
+    find 'div#flash_notice', :visible => true, :text => "Issue ##{issue.id} created."
     assert_equal issue_path(:id => issue), current_path
 
     # check issue attributes
@@ -417,7 +418,7 @@ class IssuesSystemTest < ApplicationSystemTestCase
 
     page.find('#issue_status_id').select('Assigned')
     assert_no_difference 'Issue.count' do
-      submit_buttons[0].click
+      click_button('commit')
       # wait for ajax response
       assert page.has_css?('#flash_notice')
       assert_current_path '/issues', :ignore_query => true
@@ -442,14 +443,14 @@ class IssuesSystemTest < ApplicationSystemTestCase
     # wait for ajax response
     assert page.has_select?('issue_project_id', selected: 'OnlineStore')
 
+    assert_selector 'input[type=submit]', count: 2
     submit_buttons = page.all('input[type=submit]')
-    assert_equal 2, submit_buttons.size
     assert_equal 'Move', submit_buttons[0].value
     assert_equal 'Move and follow', submit_buttons[1].value
 
     page.find('#issue_status_id').select('Feedback')
     assert_no_difference 'Issue.count' do
-      submit_buttons[1].click
+      click_button('follow')
       # wait for ajax response
       assert page.has_css?('#flash_notice')
       assert_current_path '/projects/onlinestore/issues', :ignore_query => true
@@ -506,8 +507,9 @@ class IssuesSystemTest < ApplicationSystemTestCase
     # wait for ajax response
     assert page.has_select?('issue_project_id', selected: 'OnlineStore')
 
+    assert_selector 'input[type=submit]', count: 2
     submit_buttons = page.all('input[type=submit]')
-    assert_equal 2, submit_buttons.size
+
     assert_equal 'Copy', submit_buttons[0].value
     assert_equal 'Copy and follow', submit_buttons[1].value
     page.find('#issue_priority_id').select('High')
@@ -579,7 +581,7 @@ class IssuesSystemTest < ApplicationSystemTestCase
 
     csv = CSV.read(downloaded_file("issues.csv"))
     subject_index = csv.shift.index('Subject')
-    subjects = csv.map {|row| row[subject_index]}
+    subjects = csv.pluck(subject_index)
     assert_equal subjects.sort, subjects
   end
 
@@ -644,7 +646,7 @@ class IssuesSystemTest < ApplicationSystemTestCase
     wait_for_ajax
 
     # assert log time form does not exist anymore for user without required permissions on the new project
-    assert_not page.has_css?('#log_time')
+    assert page.has_no_css?('#log_time')
   end
 
   def test_update_issue_form_should_include_add_notes_form_only_for_users_with_permission
@@ -664,6 +666,6 @@ class IssuesSystemTest < ApplicationSystemTestCase
     wait_for_ajax
 
     # assert add notes form does not exist anymore for user without required permissions on the new project
-    assert_not page.has_css?('#add_notes')
+    assert page.has_no_css?('#add_notes')
   end
 end
