@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.expand_path('../../test_helper', __FILE__)
+require_relative '../test_helper'
 
 class ProjectQueryTest < ActiveSupport::TestCase
   fixtures :projects, :users,
@@ -62,6 +62,18 @@ class ProjectQueryTest < ActiveSupport::TestCase
     assert_include :cf_3, query.available_columns.map(&:name)
   end
 
+  def test_available_display_types_should_returns_bord_and_list
+    query = ProjectQuery.new
+    query.admin_projects = nil
+    assert_equal ['board', 'list'], query.available_display_types
+  end
+
+  def test_available_display_types_should_always_returns_list_when_admin_projects_is_set
+    query = ProjectQuery.new
+    query.admin_projects = 1
+    assert_equal ['list'], query.available_display_types
+  end
+
   def test_display_type_default_should_equal_with_setting_project_list_display_type
     ProjectQuery.new.available_display_types.each do |t|
       with_settings :project_list_display_type => t do
@@ -105,4 +117,36 @@ class ProjectQueryTest < ActiveSupport::TestCase
 
     assert_nil ProjectQuery.default
   end
+
+  def test_display_type_should_returns_list_when_admin_projects_is_set
+    q = ProjectQuery.new
+    q.admin_projects = 1
+    assert_equal 'list', q.display_type
+  end
+
+  def test_project_statuses_values_should_equal_ancestors_return
+    ancestor = Query.new
+    q = ProjectQuery.new
+    assert_equal ancestor.project_statuses_values, q.project_statuses_values
+  end
+
+  def test_project_statuses_values_should_includes_project_status_archeved_when_admin_projects_is_set
+    q = ProjectQuery.new
+    q.admin_projects = 1
+    assert_includes q.project_statuses_values, [l(:project_status_archived), Project::STATUS_ARCHIVED.to_s]
+    Query.new.project_statuses_values.each do |status|
+      assert_includes q.project_statuses_values, status
+    end
+  end
+
+  def test_base_scope_should_return_visible_projects
+    q = ProjectQuery.new
+    assert_equal Project.visible, q.base_scope
+  end
+
+  def test_base_scope_should_return_all_projects_when_admin_projects_is_set
+    q = ProjectQuery.new
+    q.admin_projects = 1
+    assert_equal Project.all, q.base_scope
+  end
 end
