@@ -17,10 +17,10 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-require File.expand_path('../../test_helper', __FILE__)
+require_relative '../test_helper'
 
 class RoleTest < ActiveSupport::TestCase
-  fixtures :roles, :workflows, :trackers
+  fixtures :roles, :workflows, :trackers, :users
 
   def setup
     User.current = nil
